---
title: "Response to Reviewers"
author:
  - ^1,\*^Robin B. Trayler
  - ^1^Lauren E. Lopes
  - ^2^Patrica A. Holroyd
  - ^1^Sora L. Kim
  - ^3^John R. Southon 

mainfont: "Helvetica"
fontsize: 10pt
geometry: margin=1.0in
bibliography: ./bibtex.bib
csl: ./quaternary-geochronology.csl
tblPrefix: Table
figPrefix: Figure
secPrefix: Section
indent: true
header-includes:
    - \usepackage{lineno}
    - \linenumbers
    - \usepackage{setspace}
    - \doublespacing
---
<!-- pandoc -s -f markdown+mark -o response.docx --pdf-engine=xelatex --filter pandoc-crossref --citeproc reviewer_comments.md --reference-doc=reference.docx --> 

# Reviewer's Responses to Questions

1) Are the objectives and the rationale of the study clearly stated? Please provide suggestions to the author(s) on how to improve the clarity of the objectives and rationale of the study. Please number each suggestion so that author(s) can more easily respond.

* **Reviewer 1**: Absolutely yes.

* **Reviewer 2**: Yes. The purpose of the study is well-articulated: to devise a method to screen for collagen preservation in tar-contaminated bones.

2) If applicable, is the application/theory/method/study reported in sufficient detail to allow for its replicability and/or reproducibility? Please provide suggestions to the author(s) on how to improve the replicability/reproducibility of their study. Please number each suggestion so that the author(s) can more easily respond.

* **Reviewer 1**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []

* **Reviewer 2**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []

3) If applicable, are statistical analyses, controls, sampling mechanism, and statistical reporting (e.g., P-values, CIs, effect sizes) appropriate and well described? Please clearly indicate if the manuscript requires additional peer review by a statistician. Kindly provide suggestions to the author(s) on how to improve the statistical analyses, controls, sampling mechanism, or statistical reporting. Please number each suggestion so that the author(s) can more easily respond.

* **Reviewer 1**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []

* **Reviewer 2**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []

4) Could the manuscript benefit from additional tables or figures, or from improving or removing (some of the) existing ones? Please provide specific suggestions for improvements, removals, or additions of figures or tables. Please number each suggestion so that author(s) can more easily respond.

* **Reviewer 1**: One additional table would be useful. It would list each bone analyzed and include its museum number, taxon, skeletal element, mass, dimensions, where sampled, and percent cortical vs cancellous bone.

* **Reviewer 2**: No. 

5) If applicable, are the interpretation of results and study conclusions supported by the data? Please provide suggestions (if needed) to the author(s) on how to improve, tone down, or expand the study interpretations/conclusions. Please number each suggestion so that the author(s) can more easily respond.

* **Reviewer 1**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []
  * No changes are needed regarded interpretations.

* **Reviewer 2**: Mark as appropriate with an X:
  * Yes [X] No [] N/A []

6) Have the authors clearly emphasized the strengths of their study/theory/methods/argument? Please provide suggestions to the author(s) on how to better emphasize the strengths of their study. Please number each suggestion so that the author(s) can more easily respond.

* **Reviewer 1**: Definitely yes.

  * See attachment.

* **Reviewer 2**: Yes. They emphasize the benefits of using FTIR for this purpose.

7) Have the authors clearly stated the limitations of their study/theory/methods/argument? Please list the limitations that the author(s) need to add or emphasize. Please number each limitation so that author(s) can more easily respond.

* **Reviewer 1**: Yes

* **Reviewer 2**: Yes. The main question is the applicability to other sites, which is not possible to know in advance of a specific test.

8) Does the manuscript structure, flow or writing need improving (e.g., the addition of subheadings, shortening of text, reorganization of sections, or moving details from one section to another)? Please provide suggestions to the author(s) on how to improve the manuscript structure and flow. Please number each suggestion so that author(s) can more easily respond.

* **Reviewer 1**: Only minor grammar corrections are needed.

* **Reviewer 2**: No. It is well written and concise.

9. *Could the manuscript benefit from language editing?*

* **Reviewer 1**: No

* **Reviewer 2**: No

# Specific Comments

## Reviewer 1

* **Reviewer #1**: This is an excellent paper that needs only minor changes and possibly one additional table. Their conclusions will be extremely useful to the entire field of ^14^C. The paper will be cited as a fundamental improvement in dating lab's understanding of the principles and practices of using FTIR on fossils. The only major suggestion is that literature references should be more complete and take into account researchers two, three of four generations older than today.

> We thank the reviewer for their positive and detail feedback. 

### Line By Line Comments

* L12 	“… fossil assemblages ~~which~~ **that** reflect unique…”

> Fixed

* L14 	“…preservation of ~~organic~~ bone collagen…”[There is no inorganic bone collagen]

> Fixed

* L25	“…identifying fossils suitable for ~~tar~~ ~~extraction~~ **radiocarbon dating** and isotope analysis.”

> Fixed

* L26 	“ While our protocol and analysis ~~code~~ **codes** were developed…”

> We have left this as *code*, which is commonly used as a plural indicating a collection of individual scripts.

* L28 “…other tar seep localities ~~which~~ **that** have yielded…”

> Fixed
	
* L40	“…comes at a cost however, for ~~studies~~ **researchers**…”

> Fixed

* L41	Cite literature older than the last ten or fifteen years, especially the accomplishments of Stock, Harris, Harris, van Valkenburgh, Ho, Berger, and many others whose work is the foundation for 	this manuscript.

> We have added citations to @ho1969, @marcus1984, @stock1992, and @berger1968 to capture older radiocarbon dates and methods for tar removal. 

* L44	“radiocarbon-dead” is a colloquial term that will not be meaningful to spectroscopists and others finding the publication using keywords such as FTIR, IR-spectroscopy, etc. Use “radiocarbon-	free” or a similar, purely physics-based term.

> This sentence now reads: 

>> “Natural tar is 80-90% carbon by weight and is, by consequence of its age, radiocarbon-free”

* L46	Cite how scientists have attempted to remove tars previously, starting with Ho, Marcus and Berger (1969) and continuing to the present.

> We have added citations to @ho1969, @berger1968, and @marcus1984. 

* L47	Why is the cited method (washing with organic solvents and ultrafiltration) the best method for 	removing tars? How does it compare with Acid-Base-Acid, Ho’s ion exchange method, gelatinization, XAD, and other methods? Is “acid digestion” digestion in hot, strong HCl or the gelatin step?

> We have clarified this sentence and removed the reference to "best practice" and instead refer to it as the most common practice.

>  This has ben sentence now reads:

>> "Briefly, the current **most common** ~~best~~ practice for extracting collagen from tar impregnated fossils involves repeatedly washing an aliquot of bone powder with organic solvents (e.g., methanol, toluene, acetone, petroleum ether) followed by acid digestion (HCl) **of the bone mineral**, gelatinization **using low-molarity** HCl and finally collagen purification via ultrafiltration [@fuller2014]"

* L50	A 150 mg sample is not large. Bones commonly weigh several to tens-of-grams; the loss of 150 mg is negligible. Unless passerine birds or small rodent bones are being dated, 150 mg is an insignificant sample loss. 

> We feel that this is more of a ethical point. In the USA, destructive sampling is regulated under the Paleontological Resources Protection Act and by other legislation. Fossils in public institutions are considered public property, and destructive sampling must be done with care, and with the goal of increasing, not decreasing their scientific value. While the loss of 150 mg of bone from a large bone is not necessarily a substantial amount of its total weight, the damage done is irreversible. There should be a balance between the needs of destructive sampling and the need to preserve fossils in their pristine state for future researchers. Our methods in this paper require an order of magnitude less material and consequently do less damage to fossils. Furthermore, as the reviewer points out, 150 mg might be an entire skeletal element for small animals. For example, @fox2023 destructively analyzed 107 small mammal bones from Rancho La Brea but only 84 yielded enough collagen for a radiocarbon date. While Rancho La Brea has produced a tremendous amount of fossils, other collections are not as large and destroying fossils unnecessarily should be avoided. 

* L57	The two sites are geographically and geologically distinct. More importantly, are the tars at each site chemically different?

> Yes, the sites are geographically distinct. Geographic/ climate variability probably plays a role in the underlying taphonomic reason for differential collagen preservation between Rancho La Brea and McKittrick, however the mechanism is outside the scope of this study. To our knowledge there has not been rigorous characterization of the tar chemistry. However, our main assertion is that tar is a large carbon contaminate which is indisputably true.

* L62-4	“We used ~~this~~ **these** initial training data to identify the most useful predictors of collagen preservation **and content** ~~that can be used to predict collagen preservation~~ in other fossils.”

> Done

* L64-6	“We used these predictions of collagen content to assess the limitations of our initial training data, thereby resulting in a robust, freely available reference data set for researchers studying tar pit fossils.”

> Done

* L74	“…sandstones of the **Pliocene** Etchegoin and **Quaternary** Tulare Formations…”

> Done

* L81	“…of Technology ~~which primarily took place~~ from 1921-1927 in several pits…”

> Fixed

* L88	“…in urban Los Angeles ~~that has~~ **and have** produced a diverse fauna …”

> Fixed

* L90	“…pools of liquid asphaltum, ~~that~~ **which** act as natural traps.”

> Fixed

* L95	“Bone is a composite material with an organic and mineral component, approximately 20% organic matter and 80% mineral component, both of which…”

> Fixed

* L97	“…carbonate (CO~3~) (CO~3~^-2^) substitutions…”

> Done

* L99	“…relatively insoluble…” Insoluble in what? Distinguish among all the different ways collagen can be removed and diagenetically destroyed, e.g., oxidation, microbial decay, root-acid attack, and so forth.

> We have changed this sentence to read "relatively robust". 

* L100	“The high collagen content…” High in comparison to what? Probably write “The high protein content of bone relative to tooth enamel has made collagen… 

> This sentence now reads:

>> "The high collagen content of bone **relative to tooth enamel and dentine** has made it a tissue of choice for many paleontologists and archaeologists..." 

* L104	**Bone collagen** preservation in modern and fossil specimens is…”

    * Collagen content is most accurately determined by quantitative amino acid analysis. Cite Guiry and Szpak (2020) and fundamental, older references such as: Wyckoff, R. W., Wagner, E., Matter, P. III & Doberenz, A. R. Collagen in fossil bone. Proc. Natl Acad. Sci. USA 50, 215–218 (1963).

> We have added references to @guiry2020, and @wyckoff1963.

* L106 - 7	“The amino acid ~~profile~~ **spectra** of **modern** **bone** collagen ~~is~~ **are** ~~relatively~~ conservative across a variety of ~~taxonomic groups~~ vertebrate animals…”

> This sentence now reads" 

>> The amino acid compositions of modern bone collagen are conservative across a variety of vertebrate groups

* L109	“Low **bone** collagen yield…”

> Done

* L110	Peptide loss is more prevalent than loss of single amino acids because peptide breakage is enzyme dependent. Explain why preferential losses of peptides and amino acids will change bulk-collagen stable isotope values. Most importantly, cite work by Hare and Fogel that shows the large range in 𝛅13C and 𝛅15N values for individual amino acids in collagen. In fossil bones, the amino acid spectrum of whole bone protein, colloquially known as “collagen,” changes significantly as total “collagen” content decreases. Because each amino acid has a unique and different stable carbon and nitrogen isotope value, the bulk “collagen’s” isotope composition will change proportionally.

* Cite: P.E. Hare, et al., (1991) The isotopic composition of carbon and nitrogen in individual amino acids isolated from modern and fossil protein. Journal of Archaeological Science 18:277-292. 

> We have added citations to @hare1991. 

* L112	Publications and ^14^C lab reports more commonly use C/N instead of C:N. Use “C/N” rather than “C:N” throughout the manuscript.

> we have changed to C/N~atomic~ throughout. 

* L112 - 3	An extensive review of fossil bone isotope chemistry and how to rank bones by using %N, amino 	acid composition, and physical characteristics, is in Stafford, et al. 1988, Table 1, Geochem. Cosmochim Acta 52:2257-2267.
Amino acid analyses vs %N for modern and fossil bones are presented in Stafford, et al., 1991, Jour. Arch, Sci 18:35-72.

> We have added a reference to @staffordjr1988 to this section.

* L113	A recent paper by Henry Schwarcz is the most quantitative of any publication discussing the significance of C/N values in bone collagen. Cite: H. Schwarcz and Harmeet-Nahal (2021) Theoretical and observed C/N ratios in human bone collagen. Jour. Archaeol. Sci. vol 131 https://doi.org/10.1016/j.jas.2021.105396 

> We have expanded section 2.2 to include addition discussion of amino acid / peptide loss, and the variations in stable isotope compositions. We have added citations to @hare1991, @bada1989, @guiry2020, @wyckoff1963, and @schwarcz2021. 

* L118	“…susceptible to contamination from a variety of ~~sources~~ **other organic carbon** sources, including…” 

> Done

* L121	"...C/N~atomic~ values than the accepted ranges…” [Again, cite Schwarcz and Harmeet-Nahal (2021) instead of previous papers.]

> The value of C/N~atomic~ 3.243 given by @schwarcz2021 is explicitly a "theoretical ideal ... midpoint". The authors state:

>> "Values of C/N higher than 3.243 are likely to be due to contamination with humic matter while lower values might be due to selective loss of amino acids."

> However, they do not provide any upper and lower bounds on their estimate, and their estimate is for only one species (humans). Given that other sources such as @guiry2020 show measurable variation in C/N~atomic~ across taxonomic groups, we do not feel that the @schwarcz2021 is the current best threshold to use.

> We have revised this sentence to reflect the ambiguity in the upper limit of acceptable C/N~atomic~ values. It now reads: 

>> "In particular, lipids and humics have high carbon, but low nitrogen, contents and lead to higher C/N~atomic~ than the accepted ranges (e.g., > 3.6,  @ambrose1990; > 3.5, @vanklinken1999, > 3.5, @guiry2021)"

* L124	Why are earlier methods to purify tar-contaminated bones being excluded? People want to know the history of chemical purifications, not just what an author found in literature of the last 15-20 years. Cite the novel work of Ho and Berger and subsequent methods.

> It was not our intent to exclude older methods such as those  used by @ho1969, and @marcus1984. However, These methods have not been used in decades and have been superseded by those cited in the text. More relevant, all the fossil specimens we included in this manuscript were processed using the methods of either @coltrain2004, @fox-dobbs2006, or @fuller2014. Furthermore, the method of tar extraction used is likely irrelevant to FTIR predictions since extraction happens after FTIR data collection. 

* L127	“…is commonly dissolved using either HCl or chelating agents…” List these chelating agents and references to using EDTA.

> Done

* L130	What is “viable collagen” A large wt % yield? Good molecular integrity? Appropriate C/N values? A specific amino acid spectrum? Blaire van Valkenburgh made the same taphonomic and chemical observations being cited in this manuscript. Her data and other researchers’ should be cited.

> We use viable collagen colloquially to indicate collagen that passes standard quality control criteria (e.g., 2.9 < C/N~atomic~ < 3.6). We have changed this sentence to read: 

>> "Finally, even after these steps, not all specimens will yield collagen that meets the criteria for good preservation."

> We were unable to locate any papers where Dr. Van Valkenburgh commented on similar observations to this study. While she has a long history of taphonomy research we are unclear which papers the reviewer in indicating about "chemical observations". 

* L135 Suggest reasons why collagen recovery is so low and variable among methods.

> Collagen recovery is not that variable among methods, it is variable between fossil localities. @france2008 and @coltrain2004 used the same method on different fossil localities. This is likely a taphonomic effect that is outside the scope of this manuscript.  

* L136	Define “collagen preserved” Is this a certain yield (mg collagen/g bone), amino acid composition, etc.?

> We have added the following sentence to section 2.2:

>> "For specimens analyzed as part of this study we use a C/N~atomic~ of 2.9 - 3.6 to indicate well preserved collagen. For values taken from the literature, we rely on the original study authors assessment."

* L154	Use PO4-3 and CO3-2 since they are the inorganic components.

> These are not free ions, they are bonded in the bone mineral. 

* L167	“…of the organic collagen fraction has previously been attempted…” 

* L171	Define “viable, well-preserved collagen” in this manuscript, rather than referring the reader to publications they have to find themselves.

> We have added the following sentence to section 2.2:

>> "For specimens analyzed as part of this study we use a C/N~atomic~ of 2.9 - 3.6 to indicate well preserved collagen. For values taken from the literature, we rely on the original study authors assessment."

* L173	There are many more papers, far predating 2020, that discuss collagen composition and whether collagen is “well-preserved, moderately-preserved, poorly-preserved and whether this acid-insoluble residue is collagen, collagen-derived or non-collagenous.

> We have added references as suggested by the reviewer throughout. We do note however, that this manuscript is not a review of collagen preservation metrics. It is a method to rapidly assess if collagen that is *likely* to pass existing metrics is preserved in otherwise difficult to deal with fossils.

* L175	People familiar with the California tar pit deposits envision most fossils being large bones from large animals; however, what bones were actually sampled and where? If cortical bone was sampled, was if from the mid-shaft or towards the epiphyses? What was the thickness of the cortical bone, since absolute cortical bone thickness affects collagen preservation. “Cortical bone” from a condor is not the same as “cortical bone” from a *Smilodon* femur. What percentage of the sample was cortical versus cancellous bone? What skeletal element was selected?

* These data are important because collagen preservation is very heterogenous in fossil bones. Depending on depositional and taphonomic conditions, and even the embryology of the bone or tooth, collagen can be preserved only on the outer < 1-mm of a bone’s exterior, in the center of a 5-mm thickness of cortical bone, or in discontinuous lenses along the length of a long bone. A single sampling site is only a guess where collagen might remain and these preservation 	idiosyncrasies should be taken into account when interpreting the “presence” or “absence” of collagen based on FTIR data.

> All our samples are from cortical bone. We did not preferentially sample any particular skeletal elements since we are limited by what fossil exist from both localities. Yes some samples are from thicker cortical bone, for example condors vs horses. However, ultimately the spatial distribution of collagen preservation within individual bones is outside the scope of this study. Our interest is in screening a large number of fossils, not in identifying heterogeneities in single bones. In our experience, resampling individuals after failed attempts at collagen extraction are rare and are likely not allowed by most museums, except under very specific circumstances.

* L181	Entirely missing is a table describing each of these seventy (70) fossils bones. The table should include at a minimum, 1) taxon, 2) skeletal element, 3) mass, 4) degree of skeletal completeness, 5) Behrensmeyer score, 6) amount of cancellous vs cortical bone present and 7) was the sampled bone cancellous, cortical bone or both.

> There is a table with taxon, genus, species, weathering score, locality, previous publication, and UCMP specimen number in the included github repository, but we agree that this was not very discoverable. We will update the table to include skeletal element. As to skeletal completeness, nearly all UCMP tar-pit fossils are isolated elements. The sampled bone was cortical bone in all cases. Knowing the total bone mass is not relevant to our methods. 

> we have added the following text to the *Sample Selection* section:

>> "A complete list of samples including UCMP catalog number, locality, taxon, genus and species is available in the linked data supplement. Additional details including photographs of some specimens, skeletal element and previous publication information are available in the online UCMP database at [ucmpdb.berkeley.edu](https://ucmpdb.berkeley.edu)." 

* L192	“…absorbance bands (B1650/B605).” “**The WAMPI index** tracks bone collagen content where…”

> Done

* L198 	“...higher PCI **values** reflect greater…”

> Done

* L208	“…fossils are impregnated with **geologic oils, which have** been proposed…”

> Done
* L237	“...such that specimens ~~where~~ **with** p > 0.5 were predicted to contain collagen, while and specimens where p **was** < 0.5 were predicted to lack collagen.”

> Done

* L265	"The water-Amide-Phosphate Index was the best predictor of collagen presence or absence." This conclusion is invaluable and will significantly increase the use of FTIR at 14C labs and save technicians considerable time assessing if fossil bones are dateable or not. “Run the WAMPI index and don’t worry about other tests.”

* L267	“…the Amide-I band height, **which** directly…”

> Done

L273	“...high degrees of weathering...~~is~~ **are** somewhat predictive...”

> Done

* L278	These 235 specimens need a table with their data, as described in line 181.

> See our answer to line 181.

* L279	More precisely define “collagen preservation.” This term can have different meanings. Collagen preservation could mean how well preserved is the protein’s molecular structure. Is the collagen an intact, approximately 100 kDa protein or is it broken into smaller and smaller peptides? Collagen preservation could also mean what amount of total collagen, irrespective of its molecular configuration, is recovered after demineralization. There could be a high weight percent of either intact or fragmented collagen or a small wt % of either type. That is, distinguish between weight percent yields and the kDa size and structural integrity of the isolated collagen.

> We feel that the term "collagen preservation" is well defined earlier in the manuscript: 

>> "We considered collagen to be well-preserved and viable for isotopic analysis if it passed the standard metrics for collagen preservation (see reviews of @guiry2020; @guiry2021) as reported by the original study authors."

> While the reviewer has brought up a variety of methods to assess preservation, *most studies* use a C/N~atomic~ as the primary metric, with the @ambrose1990 (2.9-3.6; 2223 citation on google scholar), or @vanklinken1999 (3.1 -3.5; 1889 citations on google scholar) by far the most common ranges.

* L286	Figure 4 is THE most important figure of the paper and its conclusions should be stressed as strongly as possible. These results will enable other researchers to rapidly assess fossils for dating and save time and money by doing so.

> We would argue that figure 5 is the most important figure as it contains the most complete dataset, but the reviewers point stands that either figure 4 or 5 shows that FTIR is a very effective screening tool.

* The only comment regards Fig 4A and the use of “Collagen Preserved” vs “No Collagen.” These terms imply there are two distinct end members, not what actually occurs — a continuum from 20 wt % collagen to 0.000 wt%. How does any single WAMPI value relate to an actual wt % value of collagen as mg collagen/g whole bone?

* These data are the reason to eventually do two experiments related to the above question: 

1) Using the same bones that had their WAMPI measured, determine total %N on each bone and plot WAMPI vs %N. Petroleum should have negligible nitrogen, but a background value should be established. Measure %N on petroleum from a few bones and subtract that value from bone %N numbers. In other words, could a simple %N measurement provide similar conclusions as the FTIR does or is %N too variable and a worthless test?

> Yes, measuring percent nitrogen would be another way of getting at bulk collagen contents. However for screening purposes, FTIR is cheaper and faster than elemental analysis. For example, all FTIR data for this study were collected over about 8 hours of FTIR time at $15 per hour (total ~$120). The UC Merced Stable Isotope Ecosystems Laboratory charges $8.50 for an EA-IRMS measurement to determine total nitrogen and carbon contents, and each analysis takes 10 minutes, plus preparation time. For the 305 samples in this study this would equate to $2592.50 and nearly 50 hours of instrument time. 

2) Do the above %N experiment, but use quantitative amino acid analyses to establish the actual amount of protein-derived amino acids in the bone. Values would be nanomoles amino acids per mg of bone (nmol/mg) and those data would be compared to WAMPI measurements. Doing so would determine if WAMPI and AAA data were linearly related or not. Select 15-20 bones whose WAMPI values range from 1.2 to 0.4 for the test.

These %N and AAA data vs WAMPI numbers will help answer a key 14C lab question — Exactly how much collagen-derived organic matter (“collagen”) is present in a bone, is there enough for 14C dating, and how does this theoretically available mass compare to what “collagen” is actually recovered after demineralization? High WAMPI values might portend large amounts of collagen, but due to the protein’s molecular (structural) degradation, much less than expected might be obtained following decalcification.

> The reviewer is suggesting some excellent follow-up experiments and we would be interested in discussing this further. However, these experiments are clearly outside the scope of the current study. 

* L317 Replace “Which can be used…” with “This equation can be used…”

> Done

* L321	If “best preserved” equals highest weight percent yield of collagen, should a “ > value” be assigned to this “best preserved” yield? Do bones with high, medium, and low collagen yields give increasingly more inaccurate data and why? Or are the 14C dates and stable isotope values equally accurate for all collagen yields? See: Hare, et al., 1991 as an example.

* L354	A significant part of this manuscript deals with statistics of FTIR data. The authors thank Dr. Elizabeth Black for this help, but due to the importance of these statistical data, wouldn’t it be appropriate to include her as a co-author? No academic of governmental affiliation is acknowledged for Dr. Black. Her work seems essential.

> Elizabeth Black, (M.D., M.S.) is UC San Francisco Faculty. She was consulted socially on the basics of using logistic regression models and sensitivity and specificity in general terms. She played no role in data collection, analysis, and interpretation and did not contribute any code, text, or interpretations to the manuscript.

* L359	“JRS ~~extracted~~ performed collagen extractions.”

> Fixed

## Reviewer 2

This is a very clear and well-written paper on a method to characterize collagen preservation in tar-contaminated bones. Several metrics are characterized for sensitivity and specificity; one method in particular does a good job of correctly classifying bones from the two assemblages. It should be possible to extent this work to other sites as presented or by adjusting the classification threshold (preserved/not preserved). The manuscript is a good length.

> We thank the reviewer for their positive and constructive comments. 

I have some minor edits to suggest, by line number:

* line 85: or fish glues?

> This line now reads:

>> "...there is no indication that **animal-based** glues were used in preparation"

* 87-88: run-on sentence

> Fixed. This sentence now reads:

>> The Rancho La Brea tar seeps occur in the northern part of the Los Angeles Basin, south of the Santa Monica Mountains, in urban Los Angeles. The seeps have produced a diverse fauna spanning the late Pleistocene to Holocene

* 96: Ca5(PO4)3OH

> Fixed

* 138: assume this bone is uncontaminated with tar? what bone is this?
 
> Both spectra are from UCMP tar seep fossils and are contaminated with tar. The "collagen preserved" fossil is UCMP 259499 and the "no collagen" fossil is UCMP 153250. These specimens were arbitrary chosen for this figure from the larger data set. 

* 191-194: fix grammar

> Fixed

* 222: briefly give the procedure here.

> Section 3.4 has been expanded to give a brief overview of the collagen extraction procedure as outlined in @fuller2014. 

* 286: what is the computed equivalent WAMPI and PCI of tar? Would be interesting to plot this on the figure or give in the figure caption.

> We are hesitant to calculate this since we do not feel that we have sufficiently characterized the tar via FTIR to know if it exhibits consistent absorbance bands in the Amide-I and Phosphate regions. If these regions are "noisy" then calculating the WAMPI here could give substantially different and not interpretable values. 

* 282: were these selected randomly?

> The initial 235 were selected randomly from the UCMP McKittrick collection.

* 298: If these samples were selected randomly, then how can this be an improvement, rather than chance? Please clarify.

> The subsequent selection of 67 specimens was based on their WAMPI values. Some  specimens (49) were selected *because* they were predicted to have collagen, and some (18) were selected *because* they were predicted to lack collagen using the WAMPI threshold of 0.43 given in table 3.

> We have revised this sentence to now read: 

>> "From these 235 fossils we selected 67 specimens for attempted collagen extraction **based on their WAMPI values**; 18 were predicted to contain no collagen (WAMPI < 0.43) and 49 were predicted to have well preserved collagen (WAMPI > 0.43)." 

* 350-351: this should be in the journal's Supplementary Information, rather than an individual author's archive. 

> Since the data and code rely on a hierarchical, relative file structure, we will archive the GitHub repository using *Zenodo* and assign it a citable DOI prior to publication.

# References {.unnumbered}
:::{#refs}
:::